""" This module provides function to convert PDF to text """


def convert(path):
    """
    Convert the given PDF to Text

    Parameters:
    path (str): the path to the PDF file

    Returns:
    str:  the content of the PDF file

    """
    print("pdf2text.py")
